@@ -5,7 +5,7 @@ import os,shutil
 from test import fixture
 from migrate.versioning.repository import Repository
 from migrate.versioning import shell
-from sqlalchemy import BoundMetaData,Table
+from sqlalchemy import MetaData,Table
 
 class Shell(fixture.Shell):
     _cmd=os.path.join('python shell','migrate')
@@ -318,112 +318,6 @@ class TestShellDatabase(Shell,fixture.DB):
 
         self.assertSuccess(self.cmd('drop_version_control',self.url,repos_path))
     
-    @fixture.usedb()
-    def test_changes(self):
-        """Changes to an outside file shouldn't affect a migration's SQL"""
-        repos_name = 'repos_name'
-        repos_path = self.tmp()
-        script_path = self.tmp_py()
-        model_path = self.tmp_named('my_model.py')
-
-        self.assertSuccess(self.cmd('create',repos_path,repos_name))
-        self.exitcode(self.cmd('drop_version_control',self.url,repos_path))
-        self.assertSuccess(self.cmd('version_control',self.url,repos_path))
-
-        # my_model contains the text model_text_1, which declares the table 
-        # my_table. 
-        # The change script script_text creates this table in a database.
-        model_text_1 = """
-        from sqlalchemy import *
-        
-        meta = DynamicMetaData()
-        table = Table('my_table',meta,
-            Column('id',Integer,primary_key=True),
-        )
-        """.replace('\n        ','\n')
-        script_text = """
-        from sqlalchemy import *
-        from migrate import *
-        logsql=True
-        import my_model
-        
-        my_model.meta.connect(migrate_engine)
-        
-        def upgrade():
-            my_model.table.create()
-            my_model.table.insert().execute(id=1)
-        
-        def downgrade():
-            my_model.table.drop()
-        """.replace('\n        ','\n')
-        fd = open(model_path,'w')
-        fd.write(model_text_1)
-        fd.close()
-
-        fd = open(script_path,'w')
-        fd.write(script_text)
-        fd.close()
-        self.assertSuccess(self.cmd('commit',script_path,repos_path))
-
-        try:
-            self.engine.text('drop table my_table').execute()
-        except:
-            pass
-
-        self.assertEquals(self.cmd_db_version(self.url,repos_path),0)
-        self.assertSuccess(self.cmd('upgrade',self.url,repos_path))
-        self.assertEquals(self.cmd_db_version(self.url,repos_path),1)
-        # Column 'stuff' does not exist
-        self.assertRaises(Exception,self.engine.text('select stuff from my_table').execute)
-        self.assertSuccess(self.cmd('downgrade',self.url,repos_path,0))
-        self.assertEquals(self.cmd_db_version(self.url,repos_path),0)
-
-        # Now a new column is added to my_model.table. (This would need a change
-        # script, but that's irrelevant to this test.)
-        # This changes the original definition; what our change script is 
-        # dependent on. Even so, it shouldn't change the sql we generate
-        model_text_2 = """
-        from sqlalchemy import *
-        
-        meta = DynamicMetaData()
-        table = Table('my_table',meta,
-            Column('id',Integer,primary_key=True),
-            Column('stuff',String),
-        )
-        """.replace('\n        ','\n')
-        fd = open(model_path,'w')
-        fd.write(model_text_2)
-        fd.close()
-
-        self.assertEquals(self.cmd_db_version(self.url,repos_path),0)
-        self.assertSuccess(self.cmd('upgrade',self.url,repos_path))
-        self.assertEquals(self.cmd_db_version(self.url,repos_path),1)
-        # The line below means the generated SQL didn't change when the outside
-        # file changed: no 'stuff' column
-        self.assertRaises(Exception,self.engine.text('select stuff from my_table').execute)
-        self.assertSuccess(self.cmd('downgrade',self.url,repos_path,0))
-        self.assertEquals(self.cmd_db_version(self.url,repos_path),0)
-
-        # Can preview upgrades: sql
-        fd=self.execute(self.cmd('upgrade',self.url,repos_path,'--preview_py'))
-        # no upgrade executed
-        self.assertEquals(self.cmd_db_version(self.url,repos_path),0,
-            "--preview_py changed the DB") 
-        # reasonable output
-        result = fd.read()
-        self.assert_(result.lower().count('my_model.table.create') > 0)
-        self.assertSuccess(fd)
-
-        # Can preview upgrades: py
-        fd=self.execute(self.cmd('upgrade',self.url,repos_path,'--preview_sql'))
-        # no upgrade executed
-        self.assertEquals(self.cmd_db_version(self.url,repos_path),0,
-            "--preview_sql changed the DB") 
-        # reasonable output
-        result = fd.read()
-        self.assert_(result.lower().count('create table') > 0)
-        self.assertSuccess(fd)
-    
     def _run_test_sqlfile(self,upgrade_script,downgrade_script):
         upgrade_path = self.tmp_sql()
         downgrade_path = self.tmp_sql()
@@ -515,7 +409,6 @@ class TestShellDatabase(Shell,fixture.DB):
         script_text="""
         from sqlalchemy import *
         from migrate import *
-        logsql = True
         
         def upgrade():
             print 'fgsfds'
@@ -531,3 +424,31 @@ class TestShellDatabase(Shell,fixture.DB):
         self.assertFailure(self.cmd('test',script_path,repos_path,self.url))
         self.assertEquals(self.cmd_version(repos_path),0)
         self.assertEquals(self.cmd_db_version(self.url,repos_path),0)
+
+        # Nonempty script using migrate_engine should succeed
+        script_path = self.tmp_py()
+        script_text="""
+        from sqlalchemy import *
+        from migrate import *
+        
+        meta = MetaData(migrate_engine)
+        account = Table('account',meta,
+            Column('id',Integer,primary_key=True),
+            Column('login',String(40)),
+            Column('passwd',String(40)),
+        )
+        def upgrade():
+            # Upgrade operations go here. Don't create your own engine; use the engine
+            # named 'migrate_engine' imported from migrate.
+            meta.create_all()
+        
+        def downgrade():
+            # Operations to reverse the above upgrade go here.
+            meta.drop_all()
+        """.replace("\n        ","\n")
+        file=open(script_path,'w')
+        file.write(script_text)
+        file.close()
+        self.assertSuccess(self.cmd('test',script_path,repos_path,self.url))
+        self.assertEquals(self.cmd_version(repos_path),0)
+        self.assertEquals(self.cmd_db_version(self.url,repos_path),0)
